//
//  Vitamin iOS
//  Apache License 2.0
//

import UIKit

final class ColorTableViewCell: UITableViewCell {
    @IBOutlet weak var ibColorHexaLabel: UILabel!
    @IBOutlet weak var ibColorView: UIView!

    func setColor(_ color: UIColor) {
        ibColorView.backgroundColor = color
        ibColorHexaLabel.text = color.toHexString()
    }

    func setColor(_ name: String, color: UIColor) {
        ibColorView.backgroundColor = color
        ibColorHexaLabel.text = name
    }
}

private extension UIColor {
    convenience init(hex: String, alpha: CGFloat = 1.0) {
        var hexFormatted: String = hex.trimmingCharacters(in: CharacterSet.whitespacesAndNewlines).uppercased()

        if hexFormatted.hasPrefix("#") {
            hexFormatted = String(hexFormatted.dropFirst())
        }

        assert(hexFormatted.count == 6, "Invalid hex code used.")

        var rgbValue: UInt64 = 0
        Scanner(string: hexFormatted).scanHexInt64(&rgbValue)

        self.init(
            red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
            green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
            blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
            alpha: alpha
        )
    }

    func toHexString() -> String {
        var red: CGFloat = 0
        var green: CGFloat = 0
        var blue: CGFloat = 0
        var alpha: CGFloat = 0
        getRed(&red, green: &green, blue: &blue, alpha: &alpha)
        let rgb: Int = (Int)(red * 255) << 16 | (Int)(green * 255) << 8 | (Int)(blue * 255) << 0
        return String(format: "#%06x", rgb)
    }
}
